@@ -59,7 +59,7 @@ def load_data(path):
     ]
     directory_listing = list(
         filter(
-            lambda x: not re.findall(r"[CSV DATA | PLOT DATA]", x), directory_listing
+            lambda x: not re.findall(r"(CSV DATA)|(PLOT DATA)", x), directory_listing
         )
     )
     for directory in directory_listing:
